/***************************************************************************
                          gphoto_messages.h  -  description
                             -------------------
    begin                : Sun Dec 30 2001
    copyright            : (C) 2001 by Renchi Raju
    email                : renchi@green.tam.uiuc.edu
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GPHOTO_MESSAGES_H
#define GPHOTO_MESSAGES_H

#include <qobject.h>

/**
 *@author Renchi Raju
 */

class Gphoto_Messages : public QObject {

    Q_OBJECT

    friend class Gphoto_Interface;
    friend class Gphoto_Status;

public:

    static Gphoto_Messages* gpMessagesWrapper();
    static void deleteMessagesWrapper();

signals:

    void errorMessage(const QString&);
    void statusChanged(const QString&);
    void progressChanged(int);

private:

    Gphoto_Messages() : QObject() { };

    static Gphoto_Messages* gpMessages;


};

#endif
